@@ -1,7 +1,7 @@
 '''
 Date: 2023-03-08 23:10:22
 LastEditors: ThetisEliza wxf199601@gmail.com
-LastEditTime: 2023-03-10 02:19:37
+LastEditTime: 2023-03-10 14:09:50
 FilePath: /outlier/src/outlier/server.py
 '''
 import logging
@@ -23,7 +23,7 @@ from .tools.utils import gethostaddr, initlogger
 class Server(ServerBizService):
     def __init__(self, sessservice: SessionService, **kwargs) -> None:
         super().__init__(sessservice, **kwargs)
-        self.rooms: List[Room] = [Room("R1")]
+        self.rooms: List[Room] = [Room("Alpha"), Room("Bravo"), Room("Charlie")]
         self.threadpool = ThreadPool()
         self.threadpool.put_task(self._room_guard)
         self.rooms[0].lastact = datetime.now().timestamp()
